#!/usr/bin/env python3

import pytest
import os
import utils
from io import StringIO
import call_peaks_macs

test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/callPeaksMACS/'

test_data_path = os.path.dirname(os.path.abspath(__file__)) + \
		'/../../test_data/'
        

@pytest.mark.unit
def test_fragment_length():
    experiment = "experiment.tagAlign.gz"
    control = "control.tagAlign.gz"
    prefix = 'test'
    genome_size = 'hs'
    chrom_sizes = 'genomefile.txt'
    cross_qc = os.path.join(test_data_path, 'test_cross.qc')
    with pytest.raises(Exception) as excinfo:
        call_peaks_macs.call_peaks_macs(experiment, cross_qc, control, prefix, genome_size, chrom_sizes)
    assert str(excinfo.value) == "Error in cross-correlation analysis: ['0', '20', '33']"



@pytest.mark.singleend
def test_fc_signal_singleend():
    assert os.path.exists(os.path.join(test_output_path, 'ENCSR238SGC/1/', 'ENCLB144FDT.fc_signal.bw'))


@pytest.mark.singleend
def test_pvalue_signal_singleend():
    assert os.path.exists(os.path.join(test_output_path,  'ENCSR238SGC/1/', 'ENCLB144FDT.pvalue_signal.bw'))


@pytest.mark.singleend
def test_peaks_xls_singleend():
    assert os.path.exists(os.path.join(test_output_path,  'ENCSR238SGC/1/', 'ENCLB144FDT_peaks.xls'))


@pytest.mark.singleend
def test_peaks_bed_singleend():
    peak_file = test_output_path +  'ENCSR238SGC/1/' + 'ENCLB144FDT.narrowPeak'
    assert utils.count_lines(peak_file) == 226738


@pytest.mark.pairedend
def test_fc_signal_pairedend():
    assert os.path.exists(os.path.join(test_output_path, 'ENCSR729LGA/2/', 'ENCLB568IYX.fc_signal.bw'))


@pytest.mark.pairedend
def test_pvalue_signal_pairedend():
    assert os.path.exists(os.path.join(test_output_path, 'ENCSR729LGA/2/', 'ENCLB568IYX.pvalue_signal.bw'))


@pytest.mark.pairedend
def test_peaks_xls_pairedend():
    assert os.path.exists(os.path.join(test_output_path, 'ENCSR729LGA/2/', 'ENCLB568IYX_peaks.xls'))


@pytest.mark.pairedend
def test_peaks_bed_pairedend():
    peak_file = test_output_path + 'ENCSR729LGA/2/' + 'ENCLB568IYX.narrowPeak'
    assert utils.count_lines(peak_file) == 112631
